==> landtax-1.0.0-20160518.023814-5-sources.jar: cn/gtmap/landtax/model/query/SwDjQsQuery.java <==
package cn.gtmap.landtax.model.query;/**
 * Created by janeshen on 2014/8/22.
 */

import java.math.BigDecimal;
import java.util.Date;

/**
 * .
 * <p/>
 *
 * @author shenjian
 * @version V1.0, 2014/8/22
 */

public class SwDjQsQuery {
    //税源基本信息
    private String syId;
    private String gdId;
    private String bpId;
    private String sysjly;
    private String djh;
    private String dbh;
    private String syzt;
    private String bz;
    private String ishc;

    //契税信息
    private String qsId;
    private String qsSzly;
    private BigDecimal qsYnse;
    private BigDecimal qsYjne;
    private String qsJmxz;
    private String qsJspz;
    private BigDecimal qsXbjse;
    private String qsBz;
    private Date qsLrrq;
    private String qsHclx;
    private String qsZt;
    private BigDecimal qsJmse;

    //项目信息
    private String xmId;
    private String xmmc;
    private BigDecimal gdmj;
    private String qdfs;
    private BigDecimal qdjg;
    private Date gdsj;
    private String xmTdyt;
    private String xmYddw;
    private String xmXzqdm;
    private String xmTdzl;

    // 基本信息
    private String jbbId;
    private String glbm;
    private String nsrmc;
    private String zgkgDm;
    private String zgkgMc;
    private String sgyDm;
    private String sgyMc;
    private String fddbr;
    private String lxdh;
    private String zclxDm;
    private String zclxMc;
    private String hyDm;
    private String hyMc;
    private String zcdz;
    private String tddj;

    private String shxrId;
    private String excelBegin;
    private String excelEnd;
    private String ids;

    private String statue;
    private String gjzt;//宗地和供地的挂接状态 1，已经挂接，2，未挂接

    public String getSyId() {
        return syId;
    }

    public void setSyId(String syId) {
        this.syId = syId;
    }

    public String getGdId() {
        return gdId;
    }

    public void setGdId(String gdId) {
        this.gdId = gdId;
    }

    public String getBpId() {
        return bpId;
    }

    public void setBpId(String bpId) {
        this.bpId = bpId;
    }

    public String getSysjly() {
        return sysjly;
    }

    public void setSysjly(String sysjly) {
        this.sysjly = sysjly;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDbh() {
        return dbh;
    }

    public void setDbh(String dbh) {
        this.dbh = dbh;
    }

    public String getSyzt() {
        return syzt;
    }

    public void setSyzt(String syzt) {
        this.syzt = syzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIshc() {
        return ishc;
    }

    public void setIshc(String ishc) {
        this.ishc = ishc;
    }

    public String getQsId() {
        return qsId;
    }

    public void setQsId(String qsId) {
        this.qsId = qsId;
    }

    public String getQsSzly() {
        return qsSzly;
    }

    public void setQsSzly(String qsSzly) {
        this.qsSzly = qsSzly;
    }

    public BigDecimal getQsYnse() {
        return qsYnse;
    }

    public void setQsYnse(BigDecimal qsYnse) {
        this.qsYnse = qsYnse;
    }

    public BigDecimal getQsYjne() {
        return qsYjne;
    }

    public void setQsYjne(BigDecimal qsYjne) {
        this.qsYjne = qsYjne;
    }

    public String getQsJmxz() {
        return qsJmxz;
    }

    public void setQsJmxz(String qsJmxz) {
        this.qsJmxz = qsJmxz;
    }

    public String getQsJspz() {
        return qsJspz;
    }

    public void setQsJspz(String qsJspz) {
        this.qsJspz = qsJspz;
    }

    public BigDecimal getQsXbjse() {
        return qsXbjse;
    }

    public void setQsXbjse(BigDecimal qsXbjse) {
        this.qsXbjse = qsXbjse;
    }

    public String getQsBz() {
        return qsBz;
    }

    public void setQsBz(String qsBz) {
        this.qsBz = qsBz;
    }

    public Date getQsLrrq() {
        return qsLrrq;
    }

    public void setQsLrrq(Date qsLrrq) {
        this.qsLrrq = qsLrrq;
    }

    public String getXmId() {
        return xmId;
    }

    public void setXmId(String xmId) {
        this.xmId = xmId;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public BigDecimal getGdmj() {
        return gdmj;
    }

    public void setGdmj(BigDecimal gdmj) {
        this.gdmj = gdmj;
    }

    public String getQdfs() {
        return qdfs;
    }

    public void setQdfs(String qdfs) {
        this.qdfs = qdfs;
    }

    public BigDecimal getQdjg() {
        return qdjg;
    }

    public void setQdjg(BigDecimal qdjg) {
        this.qdjg = qdjg;
    }

    public Date getGdsj() {
        return gdsj;
    }

    public void setGdsj(Date gdsj) {
        this.gdsj = gdsj;
    }

    public String getXmTdyt() {
        return xmTdyt;
    }

    public void setXmTdyt(String xmTdyt) {
        this.xmTdyt = xmTdyt;
    }

    public String getXmYddw() {
        return xmYddw;
    }

    public void setXmYddw(String xmYddw) {
        this.xmYddw = xmYddw;
    }

    public String getXmXzqdm() {
        return xmXzqdm;
    }

    public void setXmXzqdm(String xmXzqdm) {
        this.xmXzqdm = xmXzqdm;
    }

    public String getXmTdzl() {
        return xmTdzl;
    }

    public void setXmTdzl(String xmTdzl) {
        this.xmTdzl = xmTdzl;
    }

    public String getJbbId() {
        return jbbId;
    }

    public void setJbbId(String jbbId) {
        this.jbbId = jbbId;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyDm() {
        return sgyDm;
    }

    public void setSgyDm(String sgyDm) {
        this.sgyDm = sgyDm;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getZclxDm() {
        return zclxDm;
    }

    public void setZclxDm(String zclxDm) {
        this.zclxDm = zclxDm;
    }

    public String getZclxMc() {
        return zclxMc;
    }

    public void setZclxMc(String zclxMc) {
        this.zclxMc = zclxMc;
    }

    public String getHyDm() {
        return hyDm;
    }

    public void setHyDm(String hyDm) {
        this.hyDm = hyDm;
    }

    public String getHyMc() {
        return hyMc;
    }

    public void setHyMc(String hyMc) {
        this.hyMc = hyMc;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getQsHclx() {
        return qsHclx;
    }

    public void setQsHclx(String qsHclx) {
        this.qsHclx = qsHclx;
    }

    public String getQsZt() {
        return qsZt;
    }

    public void setQsZt(String qsZt) {
        this.qsZt = qsZt;
    }

    public String getShxrId() {
        return shxrId;
    }

    public void setShxrId(String shxrId) {
        this.shxrId = shxrId;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getStatue() {
        return statue;
    }

    public void setStatue(String statue) {
        this.statue = statue;
    }

    public BigDecimal getQsJmse() {
        return qsJmse;
    }

    public void setQsJmse(BigDecimal qsJmse) {
        this.qsJmse = qsJmse;
    }

    public String getGjzt() {
        return gjzt;
    }

    public void setGjzt(String gjzt) {
        this.gjzt = gjzt;
    }

    public String getTddj() {
        return tddj;
    }

    public void setTddj(String tddj) {
        this.tddj = tddj;
    }
}

==> landtax-1.0.0-20180601.023313-26-sources.jar: cn/gtmap/landtax/model/query/SwDjQsQuery.java <==
package cn.gtmap.landtax.model.query;/**
 * Created by janeshen on 2014/8/22.
 */

import java.math.BigDecimal;
import java.util.Date;

/**
 * .
 * <p/>
 *
 * @author shenjian
 * @version V1.0, 2014/8/22
 */

public class SwDjQsQuery {
    //税源基本信息
    private String syId;
    private String gdId;
    private String bpId;
    private String sysjly;
    private String djh;
    private String dbh;
    private String syzt;
    private String bz;
    private String ishc;

    //契税信息
    private String qsId;
    private String qsSzly;
    private BigDecimal qsYnse;
    private BigDecimal qsYjne;
    private String qsJmxz;
    private String qsJspz;
    private BigDecimal qsXbjse;
    private String qsBz;
    private Date qsLrrq;
    private String qsHclx;
    private String qsZt;
    private BigDecimal qsJmse;

    //项目信息
    private String xmId;
    private String xmmc;
    private BigDecimal gdmj;
    private String qdfs;
    private BigDecimal qdjg;
    private Date gdsj;
    private String xmTdyt;
    private String xmYddw;
    private String xmXzqdm;
    private String xmTdzl;

    // 基本信息
    private String jbbId;
    private String glbm;
    private String nsrmc;
    private String zgkgDm;
    private String zgkgMc;
    private String sgyDm;
    private String sgyMc;
    private String fddbr;
    private String lxdh;
    private String zclxDm;
    private String zclxMc;
    private String hyDm;
    private String hyMc;
    private String zcdz;
    private String tddj;
    private String nsrsbh;

    private String shxrId;
    private String excelBegin;
    private String excelEnd;
    private String ids;

    private String statue;
    private String gjzt;//宗地和供地的挂接状态 1，已经挂接，2，未挂接

    private String zdsybz;

    public String getZdsybz() {
        return zdsybz;
    }

    public void setZdsybz(String zdsybz) {
        this.zdsybz = zdsybz;
    }


    public String getNsrsbh() {
        return nsrsbh;
    }

    public void setNsrsbh(String nsrsbh) {
        this.nsrsbh = nsrsbh;
    }
    public String getSyId() {
        return syId;
    }

    public void setSyId(String syId) {
        this.syId = syId;
    }


    public String getGdId() {
        return gdId;
    }

    public void setGdId(String gdId) {
        this.gdId = gdId;
    }

    public String getBpId() {
        return bpId;
    }

    public void setBpId(String bpId) {
        this.bpId = bpId;
    }

    public String getSysjly() {
        return sysjly;
    }

    public void setSysjly(String sysjly) {
        this.sysjly = sysjly;
    }

    public String getDjh() {
        return djh;
    }

    public void setDjh(String djh) {
        this.djh = djh;
    }

    public String getDbh() {
        return dbh;
    }

    public void setDbh(String dbh) {
        this.dbh = dbh;
    }

    public String getSyzt() {
        return syzt;
    }

    public void setSyzt(String syzt) {
        this.syzt = syzt;
    }

    public String getBz() {
        return bz;
    }

    public void setBz(String bz) {
        this.bz = bz;
    }

    public String getIshc() {
        return ishc;
    }

    public void setIshc(String ishc) {
        this.ishc = ishc;
    }

    public String getQsId() {
        return qsId;
    }

    public void setQsId(String qsId) {
        this.qsId = qsId;
    }

    public String getQsSzly() {
        return qsSzly;
    }

    public void setQsSzly(String qsSzly) {
        this.qsSzly = qsSzly;
    }

    public BigDecimal getQsYnse() {
        return qsYnse;
    }

    public void setQsYnse(BigDecimal qsYnse) {
        this.qsYnse = qsYnse;
    }

    public BigDecimal getQsYjne() {
        return qsYjne;
    }

    public void setQsYjne(BigDecimal qsYjne) {
        this.qsYjne = qsYjne;
    }

    public String getQsJmxz() {
        return qsJmxz;
    }

    public void setQsJmxz(String qsJmxz) {
        this.qsJmxz = qsJmxz;
    }

    public String getQsJspz() {
        return qsJspz;
    }

    public void setQsJspz(String qsJspz) {
        this.qsJspz = qsJspz;
    }

    public BigDecimal getQsXbjse() {
        return qsXbjse;
    }

    public void setQsXbjse(BigDecimal qsXbjse) {
        this.qsXbjse = qsXbjse;
    }

    public String getQsBz() {
        return qsBz;
    }

    public void setQsBz(String qsBz) {
        this.qsBz = qsBz;
    }

    public Date getQsLrrq() {
        return qsLrrq;
    }

    public void setQsLrrq(Date qsLrrq) {
        this.qsLrrq = qsLrrq;
    }

    public String getXmId() {
        return xmId;
    }

    public void setXmId(String xmId) {
        this.xmId = xmId;
    }

    public String getXmmc() {
        return xmmc;
    }

    public void setXmmc(String xmmc) {
        this.xmmc = xmmc;
    }

    public BigDecimal getGdmj() {
        return gdmj;
    }

    public void setGdmj(BigDecimal gdmj) {
        this.gdmj = gdmj;
    }

    public String getQdfs() {
        return qdfs;
    }

    public void setQdfs(String qdfs) {
        this.qdfs = qdfs;
    }

    public BigDecimal getQdjg() {
        return qdjg;
    }

    public void setQdjg(BigDecimal qdjg) {
        this.qdjg = qdjg;
    }

    public Date getGdsj() {
        return gdsj;
    }

    public void setGdsj(Date gdsj) {
        this.gdsj = gdsj;
    }

    public String getXmTdyt() {
        return xmTdyt;
    }

    public void setXmTdyt(String xmTdyt) {
        this.xmTdyt = xmTdyt;
    }

    public String getXmYddw() {
        return xmYddw;
    }

    public void setXmYddw(String xmYddw) {
        this.xmYddw = xmYddw;
    }

    public String getXmXzqdm() {
        return xmXzqdm;
    }

    public void setXmXzqdm(String xmXzqdm) {
        this.xmXzqdm = xmXzqdm;
    }

    public String getXmTdzl() {
        return xmTdzl;
    }

    public void setXmTdzl(String xmTdzl) {
        this.xmTdzl = xmTdzl;
    }

    public String getJbbId() {
        return jbbId;
    }

    public void setJbbId(String jbbId) {
        this.jbbId = jbbId;
    }

    public String getGlbm() {
        return glbm;
    }

    public void setGlbm(String glbm) {
        this.glbm = glbm;
    }

    public String getNsrmc() {
        return nsrmc;
    }

    public void setNsrmc(String nsrmc) {
        this.nsrmc = nsrmc;
    }

    public String getZgkgDm() {
        return zgkgDm;
    }

    public void setZgkgDm(String zgkgDm) {
        this.zgkgDm = zgkgDm;
    }

    public String getZgkgMc() {
        return zgkgMc;
    }

    public void setZgkgMc(String zgkgMc) {
        this.zgkgMc = zgkgMc;
    }

    public String getSgyDm() {
        return sgyDm;
    }

    public void setSgyDm(String sgyDm) {
        this.sgyDm = sgyDm;
    }

    public String getSgyMc() {
        return sgyMc;
    }

    public void setSgyMc(String sgyMc) {
        this.sgyMc = sgyMc;
    }

    public String getFddbr() {
        return fddbr;
    }

    public void setFddbr(String fddbr) {
        this.fddbr = fddbr;
    }

    public String getLxdh() {
        return lxdh;
    }

    public void setLxdh(String lxdh) {
        this.lxdh = lxdh;
    }

    public String getZclxDm() {
        return zclxDm;
    }

    public void setZclxDm(String zclxDm) {
        this.zclxDm = zclxDm;
    }

    public String getZclxMc() {
        return zclxMc;
    }

    public void setZclxMc(String zclxMc) {
        this.zclxMc = zclxMc;
    }

    public String getHyDm() {
        return hyDm;
    }

    public void setHyDm(String hyDm) {
        this.hyDm = hyDm;
    }

    public String getHyMc() {
        return hyMc;
    }

    public void setHyMc(String hyMc) {
        this.hyMc = hyMc;
    }

    public String getZcdz() {
        return zcdz;
    }

    public void setZcdz(String zcdz) {
        this.zcdz = zcdz;
    }

    public String getQsHclx() {
        return qsHclx;
    }

    public void setQsHclx(String qsHclx) {
        this.qsHclx = qsHclx;
    }

    public String getQsZt() {
        return qsZt;
    }

    public void setQsZt(String qsZt) {
        this.qsZt = qsZt;
    }

    public String getShxrId() {
        return shxrId;
    }

    public void setShxrId(String shxrId) {
        this.shxrId = shxrId;
    }

    public String getExcelBegin() {
        return excelBegin;
    }

    public void setExcelBegin(String excelBegin) {
        this.excelBegin = excelBegin;
    }

    public String getExcelEnd() {
        return excelEnd;
    }

    public void setExcelEnd(String excelEnd) {
        this.excelEnd = excelEnd;
    }

    public String getIds() {
        return ids;
    }

    public void setIds(String ids) {
        this.ids = ids;
    }

    public String getStatue() {
        return statue;
    }

    public void setStatue(String statue) {
        this.statue = statue;
    }

    public BigDecimal getQsJmse() {
        return qsJmse;
    }

    public void setQsJmse(BigDecimal qsJmse) {
        this.qsJmse = qsJmse;
    }

    public String getGjzt() {
        return gjzt;
    }

    public void setGjzt(String gjzt) {
        this.gjzt = gjzt;
    }

    public String getTddj() {
        return tddj;
    }

    public void setTddj(String tddj) {
        this.tddj = tddj;
    }
}
